@@ -1,4 +1,4 @@
-ClusterPurity <-
-function(ComputedClusters, TrueClasses) {
+# Cluster Purity
+ClusterPurity <- function(ComputedClusters, TrueClasses) {
   sum(apply(table(ComputedClusters,TrueClasses), 1, max)) / length(ComputedClusters)
 }
